/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergey Gorbunov [committer] */

#ifndef CbmL1Util_H
#define CbmL1Util_H 1

#include "CaTrackParam.h"
#include "CbmDefs.h"
#include "CbmL1DetectorID.h"
#include "CbmMuchTrackingInterface.h"
#include "CbmMvdTrackingInterface.h"
#include "CbmStsTrackingInterface.h"
#include "CbmTofTrackingInterface.h"
#include "CbmTrdTrackingInterface.h"
#include "Rtypes.h"

class FairTrackParam;

///
/// Collection of useful utilites for CbmL1
///
namespace cbm::L1Util
{

  /// copy fair track param to Ca track param
  cbm::algo::ca::TrackParamD ConvertTrackParam(const FairTrackParam& par);

  /// copy Ca track param to fair track param
  FairTrackParam ConvertTrackParam(const cbm::algo::ca::TrackParamD& t);

  /// convert Ca detector Id to Cbm detector Id
  inline ECbmModuleId ConvertDetSystemId(const cbm::algo::ca::EDetectorID caDetId)
  {
    switch (caDetId) {
      case cbm::algo::ca::EDetectorID::kMvd: return ECbmModuleId::kMvd;
      case cbm::algo::ca::EDetectorID::kSts: return ECbmModuleId::kSts;
      case cbm::algo::ca::EDetectorID::kMuch: return ECbmModuleId::kMuch;
      case cbm::algo::ca::EDetectorID::kTrd: return ECbmModuleId::kTrd;
      case cbm::algo::ca::EDetectorID::kTof: return ECbmModuleId::kTof;
      default: return ECbmModuleId::kNotExist;
    }
  }

  /// convert Cbm detector Id to Ca detector Id
  inline cbm::algo::ca::EDetectorID ConvertDetSystemId(const ECbmModuleId cbmDetId)
  {
    switch (cbmDetId) {
      case ECbmModuleId::kMvd: return cbm::algo::ca::EDetectorID::kMvd;
      case ECbmModuleId::kSts: return cbm::algo::ca::EDetectorID::kSts;
      case ECbmModuleId::kMuch: return cbm::algo::ca::EDetectorID::kMuch;
      case ECbmModuleId::kTrd: return cbm::algo::ca::EDetectorID::kTrd;
      case ECbmModuleId::kTof: return cbm::algo::ca::EDetectorID::kTof;
      default: return cbm::algo::ca::EDetectorID::kEND;
    }
  }

  inline const CbmTrackingDetectorInterfaceBase* GetTrackingInterface(const cbm::algo::ca::EDetectorID caDetId)
  {
    switch (caDetId) {
      case cbm::algo::ca::EDetectorID::kMvd: return CbmMvdTrackingInterface::Instance();
      case cbm::algo::ca::EDetectorID::kSts: return CbmStsTrackingInterface::Instance();
      case cbm::algo::ca::EDetectorID::kMuch: return CbmMuchTrackingInterface::Instance();
      case cbm::algo::ca::EDetectorID::kTrd: return CbmTrdTrackingInterface::Instance();
      case cbm::algo::ca::EDetectorID::kTof: return CbmTofTrackingInterface::Instance();
      default: return nullptr;
    }
  }

  inline const CbmTrackingDetectorInterfaceBase* GetTrackingInterface(const ECbmModuleId cbmDetId)
  {
    cbm::algo::ca::EDetectorID caDetId = ConvertDetSystemId(cbmDetId);
    return GetTrackingInterface(caDetId);
  }

}  // namespace cbm::L1Util

#endif
